import { SQLiteDatabase } from "expo-sqlite";
import { Property, Relation, Model, ModelValue, QueryParams, WhereCondition, PrimitiveProperty, Config, PrimaryKeyValue, PropertyAPI } from "@canvas-js/modeldb";
import { SqlitePrimitiveValue } from "./encoding.js";
export declare class ModelAPI {
    #private;
    readonly db: SQLiteDatabase;
    readonly config: Config;
    readonly model: Model;
    readonly properties: Record<string, Property>;
    readonly relations: Record<string, RelationAPI>;
    readonly relationNames: string[];
    readonly primaryProperties: PrimitiveProperty[];
    readonly mutableProperties: Property[];
    readonly codecs: Record<string, PropertyAPI<SqlitePrimitiveValue>>;
    readonly codecNames: string[];
    constructor(db: SQLiteDatabase, config: Config, model: Model);
    get(key: PrimaryKeyValue | PrimaryKeyValue[]): ModelValue | null;
    getAll(): ModelValue[];
    getMany(keys: PrimaryKeyValue[] | PrimaryKeyValue[][]): (ModelValue | null)[];
    set(value: ModelValue): void;
    private encodeProperties;
    delete(key: PrimaryKeyValue | PrimaryKeyValue[]): void;
    clear(): void;
    count(where?: WhereCondition): number;
    query(query: QueryParams): ModelValue[];
    iterate(query: QueryParams): Iterable<ModelValue>;
    private parseRecord;
    private parseQuery;
    private getSelectExpression;
    private getWhereExpression;
}
export declare class RelationAPI {
    #private;
    readonly db: SQLiteDatabase;
    readonly config: Config;
    readonly relation: Relation;
    readonly table: string;
    readonly sourceIndex: string;
    readonly targetIndex: string;
    readonly sourceColumnNames: string[];
    readonly targetColumnNames: string[];
    constructor(db: SQLiteDatabase, config: Config, relation: Relation);
    get(sourceKey: SqlitePrimitiveValue[]): SqlitePrimitiveValue[][];
    add(sourceKey: SqlitePrimitiveValue[], targetKeys: SqlitePrimitiveValue[][]): void;
    delete(sourceKey: SqlitePrimitiveValue[]): void;
    clear(): void;
}
